%define major     20
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Summary:        Library and tool to control NAT in UPnP-enabled routers
Name:           miniupnpc
Version:        2.3.2
Release:        %mkrel 1
License:        LGPLv2+
Group:          System/Libraries
URL:            http://miniupnp.free.fr/
Source:         http://miniupnp.free.fr/files/%{name}-%{version}.tar.gz
# taken from Fedora
Source1:        USAGE
Patch1:         miniupnpc-fix-pkgconfig-libdir-path.patch

BuildRequires:  cmake

%description
miniupnpc is an implementation of a UPnP client library, enabling
applications to access the services provided by an UPnP "Internet
Gateway Device" present on the network. In UPnP terminology, it is
a UPnP Control Point.

%package -n     %{libname}
Summary:        Library and tool to control NAT in UPnP-enabled routers
Group:          System/Libraries

%description -n %{libname}
miniupnpc is an implementation of a UPnP client library, enabling
applications to access the services provided by an UPnP "Internet
Gateway Device" present on the network. In UPnP terminology, it is
a UPnP Control Point.

%package -n     %{develname}
Summary:        Header files, libraries and development documentation for miniupnpc
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the header files and development documentation for
miniupnpc. If you like to develop programs using miniupnpc, you will need
to install miniupnpc-devel.

%package -n     python3-%{name}
Summary:        Python3 interface to %{name}
Requires:       %{libname} = %{version}-%{release}
BuildRequires:  pyproject-rpm-macros
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)

%description -n python3-%{name}
This package contains python3 interfaces to %{name}.

%prep
%autosetup -p2

cp -a %{SOURCE1} .

%build
%cmake -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES \
       -DCMAKE_SKIP_RPATH:BOOL=YES \
       -DUPNPC_BUILD_STATIC=FALSE
%cmake_build

### build python3 bindings
%pyproject_wheel

%install
%cmake_install

%pyproject_install
%pyproject_save_files miniupnpc

mv %{buildroot}%{_bindir}/upnpc-shared %{buildroot}%{_bindir}/upnpc
mv %{buildroot}%{_bindir}/upnp-listdevices-shared %{buildroot}%{_bindir}/upnp-listdevices
rm -f %{buildroot}%{_bindir}/external-ip.sh

%check
%make_build CPPFLAGS="-DMINIUPNPC_SET_SOCKET_TIMEOUT -I./include" check

%files
%doc Changelog.txt README USAGE
%license LICENSE
%{_bindir}/upnpc
%{_bindir}/upnp-listdevices
%{_mandir}/man3/miniupnpc.3*

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{version}

%files -n %{develname}
%{_includedir}/miniupnpc/
%{_libdir}/*.so
%{_libdir}/cmake/miniupnpc/
%{_libdir}/pkgconfig/miniupnpc.pc

%files -n python3-%{name} -f %{pyproject_files}


%changelog
* Sun May 04 2025 daviddavid <daviddavid> 2.3.2-1.mga10
+ Revision: 2180786
- new version: 2.3.2
- now libmajor is 20

* Tue Mar 04 2025 wally <wally> 2.2.8-2.mga10
+ Revision: 2160693
- fix %%check
- rebuild for python3.13

* Tue Sep 03 2024 daviddavid <daviddavid> 2.2.8-1.mga10
+ Revision: 2092900
- new version: 2.2.8
- now libmajor is 18

* Thu Mar 21 2024 daviddavid <daviddavid> 2.2.7-1.mga10
+ Revision: 2051052
- new version: 2.2.7

* Tue Jan 09 2024 daviddavid <daviddavid> 2.2.6-1.mga10
+ Revision: 2029226
- new version: 2.2.6

* Thu Dec 28 2023 daviddavid <daviddavid> 2.2.5-2.mga10
+ Revision: 2023240
- rebuild for py3.12
- switch to pyproject

* Wed Sep 20 2023 daviddavid <daviddavid> 2.2.5-1.mga10
+ Revision: 1988286
- new version: 2.2.5

* Sat Apr 22 2023 daviddavid <daviddavid> 2.2.4-2.mga9
+ Revision: 1953993
- add patch to fix libdir path in pkgconfig file

* Wed Dec 21 2022 daviddavid <daviddavid> 2.2.4-1.mga9
+ Revision: 1925507
- new version: 2.2.4

* Sat Mar 19 2022 umeabot <umeabot> 2.2.2-6.mga9
+ Revision: 1799323
- Mageia 9 Mass Rebuild

* Mon Feb 28 2022 tv <tv> 2.2.2-5.mga9
+ Revision: 1786774
- Rebuild for python-3.10

* Tue Jun 15 2021 wally <wally> 2.2.2-4.mga9
+ Revision: 1730853
- fix pkg-conf .pc file

* Tue Jun 15 2021 wally <wally> 2.2.2-3.mga9
+ Revision: 1730849
- provide pkg-conf .pc file (mga#29120)

* Thu Mar 25 2021 daviddavid <daviddavid> 2.2.2-2.mga9
+ Revision: 1710175
- rebuild for python 3.9

* Wed Mar 10 2021 daviddavid <daviddavid> 2.2.2-1.mga9
+ Revision: 1701123
- new version: 2.2.2

* Fri Dec 25 2020 wally <wally> 2.2.1-1.mga8
+ Revision: 1663720
- new version 2.2.1

* Thu Nov 19 2020 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1647721
- new version: 2.2.0

* Wed Aug 05 2020 daviddavid <daviddavid> 2.1-3.mga8
+ Revision: 1611304
- enable the python3 bindings for miniupnpc

* Tue Feb 11 2020 umeabot <umeabot> 2.1-2.mga8
+ Revision: 1488921
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Aug 24 2018 daviddavid <daviddavid> 2.1-1.mga7
+ Revision: 1253795
- new version: 2.1
- now libmajor is 17

* Mon May 15 2017 neoclust <neoclust> 2.0.20170509-1.mga6
+ Revision: 1101654
- New version - Fixes CVE-2017-8798 (mga#20851)

* Mon Feb 15 2016 umeabot <umeabot> 1.9.20151008-3.mga6
+ Revision: 961431
- Mageia 6 Mass Rebuild

* Sat Oct 31 2015 doktor5000 <doktor5000> 1.9.20151008-2.mga6
+ Revision: 896940
- reenable tests

* Tue Oct 13 2015 fwang <fwang> 1.9.20151008-1.mga6
+ Revision: 890190
- 1.9.20151008

* Sun Dec 14 2014 doktor5000 <doktor5000> 1.9.20141128-1.mga5
+ Revision: 803179
- new version 1.9.20141128
- major changed to 12
- fix library libminiupnpc.so.%%{version} linking to libminiupnpc.so.%%{major}
  o patch %%{name}-version.patch taken from Fedora
- enabled build of example commandline client binary upnpc
  o install manpage and USAGE file (latter taken from Fedora) for upnpc client
- prepare to build and enable tests, although testportlistingparse missing

* Wed Oct 15 2014 umeabot <umeabot> 1.9.20140701-4.mga5
+ Revision: 744043
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.9.20140701-3.mga5
+ Revision: 727301
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.9.20140701-2.mga5
+ Revision: 682525
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 fwang <fwang> 1.9.20140701-1.mga5
+ Revision: 660778
- 1.9.20140701

* Wed May 14 2014 luigiwalser <luigiwalser> 1.9-1.mga5
+ Revision: 622807
- 1.9 (fixes DoS issue)
- library major is now 10

* Sat Oct 19 2013 umeabot <umeabot> 1.8-2.mga4
+ Revision: 533952
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 fwang <fwang> 1.8-1.mga4
+ Revision: 475855
- new version 1.8

* Sat Jan 12 2013 umeabot <umeabot> 1.6-3.mga3
+ Revision: 360104
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 07 2011 fwang <fwang> 1.6-2.mga2
+ Revision: 132178
- commit header patch
- update header list
- imported package miniupnpc

